@@ -94,6 +94,7 @@ typedef enum _tagMEDIA_SIZE_ID_ {
     EPS_MSID_B6               , /* 46  0x2E  [128.000,182.000]  */
     EPS_MSID_KAKU_20          , /* 47  0x2F  [229.000,324.000]  */
     EPS_MSID_A5_24HOLE        , /* 48  0x30  [148.000,210.000]  */
+	EPS_MSID_CHOKEI_40     =52, /* 52  0x34  [ 90.000,225.000]  */
     EPS_MSID_A3NOBI        =61, /* 61  0x3D  [329.000,483.000]  */
     EPS_MSID_A3               , /* 62  0x3E  [297.000,420.000]  */
     EPS_MSID_B4               , /* 63  0x3F  [257.000,364.000]  */
@@ -104,10 +105,20 @@ typedef enum _tagMEDIA_SIZE_ID_ {
     EPS_MSID_USC              , /* 68  0x44  [431.800,558.800]  */
     EPS_MSID_10X12            , /* 69  0x45  [254.000,304.800]  */
     EPS_MSID_12X12            , /* 70  0x46  [304.800,304.800]  */
+	EPS_MSID_SP1			  , /* 71  0x47  [210.000,270.000]  */
+	EPS_MSID_SP2              , /* 72  0x48  [210.000,149.000]  */
+	EPS_MSID_SP3              , /* 73  0x49  [100.000,170.000]  */
+	EPS_MSID_SP4              , /* 74  0x4A  [130.000,182.000]  */
+	EPS_MSID_SP5              , /* 75  0x4B  [192.000,132.000]  */
+	EPS_MSID_16K              , /* 76  0x4C  [195.000,270.000]  */
+	EPS_MSID_8K               , /* 77  0x4D  [270.000,390.000]  */
     EPS_MSID_USER          =99, /* 99  0x63  [  0.000,  0.000]  */
+    EPS_MSID_HALFCUT      =128, /*128  0x80  [356.000,432.000]  */
+    EPS_MSID_16X20            , /*129  0x81  [406.400,508.000]  */
     EPS_MSID_UNKNOWN       =0xff/* unknown                      */
 } MEDIA_SIZE_ID;
 
+
         /*** Media Data Struct                                                          */
         /*** ---------------------------------------------------------------------------*/
 typedef struct _tagEPS_MEDIA_INFO_ {
@@ -126,66 +137,76 @@ typedef struct _tagEPS_MEDIA_INFO_ {
         /*** ---------------------------------------------------------------------------*/
 static const EPS_MEDIA_INFO epsMediaSize[] = {
 /*          ID              PaperW/L    3mm W/L     0mm L/T   0mm W/L   */
-{	EPS_MSID_A4,            2976, 4209, 2892, 4125, -36, -42, 3048, 4321 },
-{	EPS_MSID_LETTER,        3060, 3960, 2976, 3876, -36, -42, 3132, 4072 },
-{	EPS_MSID_LEGAL,         3060, 5040, 2976, 4956, -36, -42, 3132, 5152 },
-{	EPS_MSID_A5,            2098, 2976, 2014, 2892, -36, -42, 2170, 3088 },
-{	EPS_MSID_A6,            1488, 2098, 1404, 2014, -36, -42, 1560, 2210 },
-{	EPS_MSID_B5,            2579, 3642, 2495, 3558, -36, -42, 2651, 3754 },
-{	EPS_MSID_EXECUTIVE,     2610, 3780, 2526, 3696, -36, -42, 2682, 3892 },
-{	EPS_MSID_HALFLETTER,    1980, 3060, 1896, 2976, -36, -42, 2052, 3172 },
-{	EPS_MSID_PANORAMIC,     2976, 8419, 2892, 8335, -36, -42, 3048, 8531 },
-{	EPS_MSID_TRIM_4X6,      1610, 2330, 1526, 2246, -36, -42, 1682, 2442 },
-{	EPS_MSID_4X6,           1440, 2160, 1356, 2076, -36, -42, 1512, 2272 },
-{	EPS_MSID_5X8,           1800, 2880, 1716, 2796, -36, -42, 1872, 2992 },
-{	EPS_MSID_8X10,          2880, 3600, 2796, 3516, -36, -42, 2952, 3712 },
-{	EPS_MSID_10X15,         1417, 2125, 1333, 2041, -36, -42, 1489, 2237 },
-{	EPS_MSID_200X300,       3061, 4790, 2977, 4706, -36, -42, 3133, 4902 },
-{	EPS_MSID_L,             1260, 1800, 1176, 1716, -36, -42, 1332, 1912 },
-{	EPS_MSID_POSTCARD,      1417, 2098, 1333, 2013, -36, -42, 1489, 2210 },
-{	EPS_MSID_DBLPOSTCARD,   2834, 2097, 2750, 2013, -36, -42, 2906, 2209 },
-{   EPS_MSID_ENV_10_L,      3420, 1485, 3336, 1401, -36, -42, 3492, 1597 },
-{   EPS_MSID_ENV_C6_L,      2296, 1616, 2212, 1532, -36, -42, 2368, 1728 },
-{   EPS_MSID_ENV_DL_L,      3118, 1559, 3034, 1475, -36, -42, 3190, 1671 },
-{   EPS_MSID_NEWEVN_L,      3118, 1871, 3034, 1787, -36, -42, 3190, 1983 },
-{	EPS_MSID_CHOKEI_3,      1700, 3330, 1560, 3005, -36, -42, 1772, 3442 },
-{	EPS_MSID_CHOKEI_4,      1275, 2905, 1135, 2580, -36, -42, 1347, 3017 },
-{	EPS_MSID_YOKEI_1,       1701, 2494, 1561, 2169, -36, -42, 1773, 2606 },
-{	EPS_MSID_YOKEI_2,       1616, 2296, 1476, 1971, -36, -42, 1688, 2408 },
-{	EPS_MSID_YOKEI_3,       1389, 2098, 1249, 1773, -36, -42, 1461, 2210 },
-{	EPS_MSID_YOKEI_4,       1488, 3330, 1348, 3005, -36, -42, 1560, 3442 },
-{	EPS_MSID_2L,            1800, 2522, 1716, 2436, -36, -42, 1872, 2634 },
-{	EPS_MSID_ENV_10_P,      1485, 3420, 1345, 3095, -36, -42, 1557, 3532 },
-{	EPS_MSID_ENV_C6_P,      1615, 2296, 1475, 1971, -36, -42, 1687, 2408 },
-{	EPS_MSID_ENV_DL_P,      1559, 3118, 1419, 2793, -36, -42, 1631, 3230 },
-{	EPS_MSID_NEWENV_P,      1871, 3118, 1731, 2793, -36, -42, 1943, 3230 },
-{	EPS_MSID_MEISHI,        1261,  779, 1177,  695, -36, -42, 1333,  891 },
-{	EPS_MSID_BUZCARD_89X50, 1261,  709, 1177,  625, -36, -42, 1333,  821 },
-{	EPS_MSID_CARD_54X86,     765, 1219,  681, 1135, -36, -42,  837, 1331 },
-{	EPS_MSID_BUZCARD_55X91,  780, 1290,  696, 1206, -36, -42,  852, 1402 },
-{	EPS_MSID_ALBUM_L,       1800, 2607, 1716, 2523, -36, -42, 1872, 2719 },
-{	EPS_MSID_ALBUM_A5,      2976, 4294, 2892, 4210, -36, -42, 3048, 4406 },
-{	EPS_MSID_PALBUM_L_L,    1800, 1260, 1716, 1176, -36, -42, 1872, 1372 },
-{	EPS_MSID_PALBUM_2L,     1800, 2521, 1716, 2437, -36, -42, 1872, 2633 },
-{	EPS_MSID_PALBUM_A5_L,   2976, 2101, 2892, 2017, -36, -42, 3048, 2213 },
-{	EPS_MSID_PALBUM_A4,     2976, 4203, 2892, 4119, -36, -42, 3048, 4315 },
-{	EPS_MSID_HIVISION,      1440, 2560, 1356, 2476, -36, -42, 1512, 2672 },
-{   EPS_MSID_KAKU_2,        3401, 4705, 2977, 4380, -36, -42, 3472, 4817 },
-{   EPS_MSID_ENV_C4_P,      3245, 4592, 2963, 4267, -36, -42, 3317, 4422 },
-{   EPS_MSID_B6,            1814, 2580, 1730, 2496, -36, -42, 1886, 2692 },
-{   EPS_MSID_KAKU_20,       3245, 4592, 2963, 4267, -36, -42, 3317, 4422 },
-{	EPS_MSID_A5_24HOLE,     2098, 2976, 1816, 2694, -36, -42, 2170, 3088 },
-{	EPS_MSID_A3NOBI,        4663, 6846, 4579, 6762, -48, -42, 4758, 6957 },
-{	EPS_MSID_A3,            4209, 5953, 4125, 5869, -48, -42, 4305, 6064 },
-{	EPS_MSID_B4,            3643, 5159, 3559, 5075, -48, -42, 3739, 5271 },
-{	EPS_MSID_USB,           3960, 6120, 3876, 6036, -48, -42, 4056, 6232 },
-{	EPS_MSID_11X14,         3960, 5040, 3876, 4956, -48, -42, 4056, 5152 },
-{	EPS_MSID_B3,            5159, 7299, 5075, 7215, -48, -42, 5255, 7397 },
-{	EPS_MSID_A2,            5953, 8419, 5869, 8335, -48, -42, 6049, 8531 },
-{	EPS_MSID_USC,           6120, 7920, 6036, 7836, -48, -42, 6216, 8032 },
-{	EPS_MSID_10X12,         3600, 4320, 3516, 4236, -48, -42, 3696, 4432 },
-{	EPS_MSID_12X12,         4320, 4320, 4236, 4236, -48, -42, 4416, 4432 },
-{   EPS_MSID_USER,              0,   0,    0,    0, -36, -42,    0,    0 },
+{	EPS_MSID_A4, 			2976, 4209, 2892, 4125, -36, -42, 3048, 4321 },
+{	EPS_MSID_LETTER, 		3060, 3960, 2976, 3876, -36, -42, 3132, 4072 },
+{	EPS_MSID_LEGAL, 		3060, 5040, 2976, 4956, -36, -42, 3132, 5152 },
+{	EPS_MSID_A5, 			2098, 2976, 2014, 2892, -36, -42, 2170, 3088 },
+{	EPS_MSID_A6, 			1488, 2098, 1404, 2014, -36, -42, 1560, 2210 },
+{	EPS_MSID_B5, 			2580, 3643, 2496, 3559, -36, -42, 2652, 3755 },
+{	EPS_MSID_EXECUTIVE, 	2611, 3780, 2527, 3696, -36, -42, 2683, 3892 },
+{	EPS_MSID_HALFLETTER,	1980, 3060, 1896, 2976, -36, -42, 2052, 3172 },
+{	EPS_MSID_PANORAMIC, 	2976, 8419, 2892, 8335, -36, -42, 3048, 8531 },
+{	EPS_MSID_TRIM_4X6, 		1610, 2330, 1526, 2246, -36, -42, 1682, 2442 },
+{	EPS_MSID_4X6, 			1440, 2160, 1356, 2076, -36, -42, 1512, 2272 },
+{	EPS_MSID_5X8, 			1800, 2880, 1716, 2796, -36, -42, 1872, 2992 },
+{	EPS_MSID_8X10, 			2880, 3600, 2796, 3516, -36, -42, 2952, 3712 },
+{	EPS_MSID_10X15, 		1417, 2125, 1333, 2041, -36, -42, 1489, 2237 },
+{	EPS_MSID_200X300, 		3061, 4790, 2977, 4706, -36, -42, 3133, 4902 },
+{	EPS_MSID_L, 			1261, 1800, 1177, 1716, -36, -42, 1333, 1912 },
+{	EPS_MSID_POSTCARD, 		1417, 2098, 1333, 2014, -36, -42, 1489, 2210 },
+{	EPS_MSID_DBLPOSTCARD,	2835, 2098, 2751, 2014, -36, -42, 2907, 2210 },
+{	EPS_MSID_ENV_10_L, 		3420, 1485, 3336, 1401, -36, -42, 3492, 1597 },
+{	EPS_MSID_ENV_C6_L, 		2296, 1616, 2212, 1532, -36, -42, 2368, 1728 },
+{	EPS_MSID_ENV_DL_L, 		3118, 1559, 3034, 1475, -36, -42, 3190, 1671 },
+{	EPS_MSID_NEWEVN_L, 		3118, 1871, 3034, 1787, -36, -42, 3190, 1983 },
+{	EPS_MSID_CHOKEI_3, 		1701, 3331, 1561, 3006, -36, -42, 1773, 3443 },
+{	EPS_MSID_CHOKEI_4, 		1276, 2906, 1136, 2581, -36, -42, 1348, 3018 },
+{	EPS_MSID_YOKEI_1, 		1701, 2494, 1561, 2169, -36, -42, 1773, 2606 },
+{	EPS_MSID_YOKEI_2, 		1616, 2296, 1476, 1971, -36, -42, 1688, 2408 },
+{	EPS_MSID_YOKEI_3, 		1389, 2098, 1249, 1773, -36, -42, 1461, 2210 },
+{	EPS_MSID_YOKEI_4, 		1488, 3331, 1348, 3006, -36, -42, 1560, 3443 },
+{	EPS_MSID_2L, 			1800, 2522, 1716, 2438, -36, -42, 1872, 2634 },
+{	EPS_MSID_ENV_10_P, 		1485, 3420, 1345, 3095, -36, -42, 1557, 3532 },
+{	EPS_MSID_ENV_C6_P, 		1616, 2296, 1476, 1971, -36, -42, 1688, 2408 },
+{	EPS_MSID_ENV_DL_P, 		1559, 3118, 1419, 2793, -36, -42, 1631, 3230 },
+{	EPS_MSID_NEWENV_P, 		1871, 3118, 1731, 2793, -36, -42, 1943, 3230 },
+{	EPS_MSID_MEISHI, 		1261, 779, 1177, 695, -36, -42, 1333, 891 },
+{	EPS_MSID_BUZCARD_89X50,	1261, 709, 1177, 625, -36, -42, 1333, 821 },
+{	EPS_MSID_CARD_54X86,765,1219, 681, 1135, -36, -42, 837, 1331 },
+{	EPS_MSID_BUZCARD_55X91,	780, 1290, 696, 1206, -36, -42, 852, 1402 },
+{	EPS_MSID_ALBUM_L, 		1800, 2607, 1716, 2523, -36, -42, 1872, 2719 },
+{	EPS_MSID_ALBUM_A5, 		2976, 4294, 2892, 4210, -36, -42, 3048, 4406 },
+{	EPS_MSID_PALBUM_L_L,	1800, 1260, 1716, 1176, -36, -42, 1872, 1372 },
+{	EPS_MSID_PALBUM_2L,		1800, 2521, 1716, 2437, -36, -42, 1872, 2633 },
+{	EPS_MSID_PALBUM_A5_L,	2976, 2101, 2892, 2017, -36, -42, 3048, 2213 },
+{	EPS_MSID_PALBUM_A4,		2976, 4203, 2892, 4119, -36, -42, 3048, 4315 },
+{	EPS_MSID_HIVISION, 		1440, 2560, 1356, 2476, -36, -42, 1512, 2672 },
+{	EPS_MSID_KAKU_2, 		3401, 4705, 2977, 4380, -36, -42, 3473, 4817 },
+{	EPS_MSID_ENV_C4_P, 		3245, 4592, 2977, 4267, -36, -42, 3317, 4704 },
+{	EPS_MSID_B6, 			1814, 2580, 1730, 2496, -48, -42, 1910, 2692 },
+{	EPS_MSID_KAKU_20, 		3245, 4592, 2977, 4267, -36, -42, 3317, 4704 },
+{	EPS_MSID_A5_24HOLE,		2098, 2976, 1816, 2694, -36, -42, 2170, 3088 },
+{	EPS_MSID_CHOKEI_40,		1276, 3189, 1136, 2736, -36, -42, 1348, 3301 },
+{	EPS_MSID_A3NOBI, 		4663, 6846, 4579, 6762, -48, -42, 4759, 6958 },
+{	EPS_MSID_A3, 			4209, 5953, 4125, 5869, -48, -42, 4305, 6065 },
+{	EPS_MSID_B4, 			3643, 5159, 3559, 5075, -48, -42, 3739, 5271 },
+{	EPS_MSID_USB, 			3960, 6120, 3876, 6036, -48, -42, 4056, 6232 },
+{	EPS_MSID_11X14, 		3960, 5040, 3876, 4956, -48, -42, 4056, 5152 },
+{	EPS_MSID_B3, 			5159, 7299, 5075, 7215, -48, -42, 5255, 7411 },
+{	EPS_MSID_A2, 			5953, 8419, 5869, 8335, -48, -42, 6049, 8531 },
+{	EPS_MSID_USC, 			6120, 7920, 6036, 7836, -48, -42, 6216, 8032 },
+{	EPS_MSID_10X12, 		3600, 4320, 3516, 4236, -48, -42, 3696, 4432 },
+{	EPS_MSID_12X12, 		4320, 4320, 4236, 4236, -48, -42, 4416, 4432 },
+{	EPS_MSID_SP1, 			2976, 3827, 2892, 3743, -36, -42, 3048, 3939 },
+{	EPS_MSID_SP2, 			2976, 2112, 2892, 2028, -36, -42, 3048, 2224 },
+{	EPS_MSID_SP3, 			1417, 2409, 1333, 2325, -36, -42, 1489, 2521 },
+{	EPS_MSID_SP4, 			1843, 2580, 1759, 2496, -36, -42, 1915, 2692 },
+{	EPS_MSID_SP5, 			2721, 1871, 2637, 1787, -36, -42, 2793, 1983 },
+{	EPS_MSID_16K, 			2764, 3827, 2680, 3743, -36, -42, 2836, 3939 },
+{	EPS_MSID_8K, 			3827, 5528, 3743, 5444, -36, -42, 3899, 5640 },
+{   EPS_MSID_USER,             0,    0,    0,    0, -36, -42,    0,    0 },
+{	EPS_MSID_HALFCUT, 		5040, 6120, 4956, 6036, -36, -42, 5112, 6232 },
+{	EPS_MSID_16X20, 		5760, 7200, 5676, 7116, -36, -42, 5832, 7312 },
 {   -1,                         0,   0,    0,    0,   0,   0,    0,    0 }
 };
 
@@ -196,66 +217,76 @@ static const EPS_MEDIA_INFO epsMediaSize[] = {
         /*** ---------------------------------------------------------------------------*/
 static const EPS_MEDIA_INFO epsMediaSize300[] = {
 /*          ID              PaperW/L    3mm W/L     0mm L/T   0mm W/L   */
-{   EPS_MSID_A4,            2480, 3507, 2410, 3437, -30, -35, 2540, 3601 },
-{   EPS_MSID_LETTER,        2550, 3300, 2480, 3230, -30, -35, 2610, 3394 },
-{   EPS_MSID_LEGAL,         2550, 4200, 2480, 4130, -30, -35, 2610, 4294 },
-{   EPS_MSID_A5,            1748, 2480, 1678, 2410, -30, -35, 1808, 2574 },
-{   EPS_MSID_A6,            1240, 1748, 1170, 1678, -30, -35, 1300, 1842 },
-{   EPS_MSID_B5,            2149, 3035, 2079, 2965, -30, -35, 2209, 3129 },
-{   EPS_MSID_EXECUTIVE,     2175, 3150, 2105, 3080, -30, -35, 2235, 3244 },
-{   EPS_MSID_HALFLETTER,    1650, 2550, 1580, 2480, -30, -35, 1710, 2644 },
-{   EPS_MSID_PANORAMIC,     2480, 7015, 2410, 6945, -30, -35, 2540, 7109 },
-{   EPS_MSID_TRIM_4X6,      1334, 1937, 1264, 1867, -30, -35, 1394, 2031 },
-{   EPS_MSID_4X6,           1200, 1800, 1130, 1730, -30, -35, 1260, 1894 },
-{   EPS_MSID_5X8,           1500, 2400, 1430, 2330, -30, -35, 1560, 2494 },
-{   EPS_MSID_8X10,          2400, 3000, 2330, 2930, -30, -35, 2460, 3094 },
-{   EPS_MSID_10X15,         1181, 1171, 1111, 1101, -30, -35, 1241, 1265 },
-{   EPS_MSID_200X300,       2362, 3543, 2292, 3473, -30, -35, 2422, 3637 },
-{   EPS_MSID_L,             1051, 1500,  981, 1430, -30, -35, 1111, 1594 },
-{   EPS_MSID_POSTCARD,      1181, 1748, 1111, 1678, -30, -35, 1241, 1842 },
-{   EPS_MSID_DBLPOSTCARD,   2362, 1748, 2292, 1678, -30, -35, 2422, 1842 },
-{   EPS_MSID_ENV_10_L,      2850, 1238, 2780, 1168, -30, -35, 2910, 1331 }, 
-{   EPS_MSID_ENV_C6_L,      1913, 1347, 1843, 1277, -30, -35, 1973, 1440 }, 
-{   EPS_MSID_ENV_DL_L,      2598, 1299, 2528, 1229, -30, -35, 2658, 1392 }, 
-{   EPS_MSID_NEWEVN_L,      2598, 1559, 2528, 1489, -30, -35, 2658, 1652 }, 
-{   EPS_MSID_CHOKEI_3,      1417, 2775, 1299, 2504, -30, -35, 1477, 2869 },
-{   EPS_MSID_CHOKEI_4,      1063, 2421,  945, 2150, -30, -35, 1123, 2515 },
-{   EPS_MSID_YOKEI_1,       1417, 2078, 1299, 1807, -30, -35, 1477, 2172 },
-{   EPS_MSID_YOKEI_2,       1346, 1913, 1228, 1642, -30, -35, 1406, 2007 },
-{   EPS_MSID_YOKEI_3,       1157, 1748, 1039, 1477, -30, -35, 1217, 1842 },
-{   EPS_MSID_YOKEI_4,       1240, 2775, 1122, 2504, -30, -35, 1300, 2869 },
-{   EPS_MSID_2L,            1500, 2102, 1430, 2032, -30, -35, 1560, 2196 },
-{   EPS_MSID_ENV_10_P,      1238, 2850, 1120, 2579, -30, -35, 1298, 2944 },
-{   EPS_MSID_ENV_C6_P,      1346, 1913, 1228, 1642, -30, -35, 1406, 2007 },
-{   EPS_MSID_ENV_DL_P,      1299, 2598, 1181, 2327, -30, -35, 1359, 2692 },
-{   EPS_MSID_NEWENV_P,      1535, 2598, 1417, 2327, -30, -35, 1595, 2692 },
-{   EPS_MSID_MEISHI,        1051,  650,  981,  580, -30, -35, 1111,  744 },
-{   EPS_MSID_BUZCARD_89X50, 1051,  590,  981,  520, -30, -35, 1111,  684 },
-{   EPS_MSID_CARD_54X86,     637, 1015,  567,  945, -30, -35,  697, 1109 },
-{   EPS_MSID_BUZCARD_55X91,  650, 1074,  580, 1004, -30, -35,  710, 1168 },
-{   EPS_MSID_ALBUM_L,       1500, 2173, 1430, 2103, -30, -35, 1560, 2267 },
-{   EPS_MSID_ALBUM_A5,      2480, 3578, 2410, 3508, -30, -35, 2540, 3672 },
-{   EPS_MSID_PALBUM_L_L,    1500, 1051, 1430,  981, -30, -35, 1560, 1145 },
-{   EPS_MSID_PALBUM_2L,     1500, 2102, 1430, 2032, -30, -35, 1560, 2196 },
-{   EPS_MSID_PALBUM_A5_L,   2480, 1748, 2410, 1678, -30, -35, 2540, 1842 },
-{   EPS_MSID_PALBUM_A4,     2480, 3507, 2410, 3437, -30, -35, 2540, 3601 },
-{   EPS_MSID_HIVISION,      1200, 2133, 1130, 2063, -30, -35, 1260, 2227 },
-{   EPS_MSID_KAKU_2,        2834, 3921, 2480, 3650, -30, -35, 2894, 4010 },
-{   EPS_MSID_ENV_C4_P,      2704, 3826, 2468, 3555, -30, -35, 2764, 3919 },
-{   EPS_MSID_B6,            1512, 2150, 1442, 2080, -30, -35, 1572, 2244 },
-{   EPS_MSID_KAKU_20,       2704, 3826, 2468, 3555, -30, -35, 2764, 3919 },
-{   EPS_MSID_A5_24HOLE,     1748, 2480, 1513, 2410, -30, -35, 1808, 2574 },
-{   EPS_MSID_A3NOBI,        3885, 5704, 3815, 5634, -42, -35, 3969, 5798 },
-{   EPS_MSID_A3,            3507, 4960, 3437, 4890, -42, -35, 3591, 5054 },
-{   EPS_MSID_B4,            3035, 4299, 2965, 4229, -42, -35, 3119, 4393 },
-{   EPS_MSID_USB,           3300, 5100, 3230, 5030, -42, -35, 3384, 5194 },
-{   EPS_MSID_11X14,         3300, 4200, 3230, 4130, -42, -35, 3384, 4294 },
-{   EPS_MSID_B3,            4299, 6082, 4229, 6012, -42, -35, 4383, 6176 },
-{   EPS_MSID_A2,            4960, 7015, 4890, 6945, -42, -35, 5044, 7109 },
-{   EPS_MSID_USC,           5100, 6600, 5030, 6530, -42, -35, 5184, 6694 },
-{   EPS_MSID_10X12,         3000, 3600, 2930, 3530, -42, -35, 3084, 3694 },
-{   EPS_MSID_12X12,         3600, 3600, 3530, 3530, -42, -35, 3684, 3694 },
+{	EPS_MSID_A4, 			2480, 3507, 2410, 3437, -30, -35, 2540, 3601 },
+{	EPS_MSID_LETTER, 		2550, 3300, 2480, 3230, -30, -35, 2610, 3394 },
+{	EPS_MSID_LEGAL, 		2550, 4200, 2480, 4130, -30, -35, 2610, 4294 },
+{	EPS_MSID_A5, 			1748, 2480, 1678, 2410, -30, -35, 1808, 2574 },
+{	EPS_MSID_A6, 			1240, 1748, 1170, 1678, -30, -35, 1300, 1842 },
+{	EPS_MSID_B5, 			2149, 3035, 2079, 2965, -30, -35, 2209, 3129 },
+{	EPS_MSID_EXECUTIVE, 	2175, 3150, 2105, 3080, -30, -35, 2235, 3244 },
+{	EPS_MSID_HALFLETTER, 	1650, 2550, 1580, 2480, -30, -35, 1710, 2644 },
+{	EPS_MSID_PANORAMIC, 	2480, 7015, 2410, 6945, -30, -35, 2540, 7109 },
+{	EPS_MSID_TRIM_4X6, 		1334, 1937, 1264, 1867, -30, -35, 1394, 2031 },
+{	EPS_MSID_4X6, 			1200, 1800, 1130, 1730, -30, -35, 1260, 1894 },
+{	EPS_MSID_5X8, 			1500, 2400, 1430, 2330, -30, -35, 1560, 2494 },
+{	EPS_MSID_8X10, 			2400, 3000, 2330, 2930, -30, -35, 2460, 3094 },
+{	EPS_MSID_10X15, 		1181, 1171, 1111, 1101, -30, -35, 1241, 1265 },
+{	EPS_MSID_200X300, 		2362, 3543, 2292, 3473, -30, -35, 2422, 3637 },
+{	EPS_MSID_L, 			1051, 1500, 981, 1430, -30, -35, 1111, 1594 },
+{	EPS_MSID_POSTCARD, 		1181, 1748, 1111, 1678, -30, -35, 1241, 1842 },
+{	EPS_MSID_DBLPOSTCARD, 	2362, 1748, 2292, 1678, -30, -35, 2422, 1842 },
+{	EPS_MSID_ENV_10_L, 		2850, 1238, 2780, 1168, -30, -35, 2910, 1332 },
+{	EPS_MSID_ENV_C6_L, 		1913, 1346, 1843, 1276, -30, -35, 1973, 1440 },
+{	EPS_MSID_ENV_DL_L, 		2598, 1299, 2528, 1229, -30, -35, 2658, 1393 },
+{	EPS_MSID_NEWEVN_L, 		2598, 1535, 2528, 1465, -30, -35, 2658, 1629 },
+{	EPS_MSID_CHOKEI_3, 		1417, 2775, 1299, 2504, -30, -35, 1477, 2869 },
+{	EPS_MSID_CHOKEI_4, 		1063, 2421, 945, 2150, -30, -35, 1123, 2515 },
+{	EPS_MSID_YOKEI_1, 		1417, 2078, 1299, 1807, -30, -35, 1477, 2172 },
+{	EPS_MSID_YOKEI_2, 		1346, 1913, 1228, 1642, -30, -35, 1406, 2007 },
+{	EPS_MSID_YOKEI_3, 		1157, 1748, 1039, 1477, -30, -35, 1217, 1842 },
+{	EPS_MSID_YOKEI_4, 		1240, 2775, 1122, 2504, -30, -35, 1300, 2869 },
+{	EPS_MSID_2L, 			1500, 2102, 1430, 2032, -30, -35, 1560, 2196 },
+{	EPS_MSID_ENV_10_P, 		1238, 2850, 1120, 2579, -30, -35, 1298, 2944 },
+{	EPS_MSID_ENV_C6_P, 		1346, 1913, 1228, 1642, -30, -35, 1406, 2007 },
+{	EPS_MSID_ENV_DL_P, 		1299, 2598, 1181, 2327, -30, -35, 1359, 2692 },
+{	EPS_MSID_NEWENV_P, 		1535, 2598, 1417, 2327, -30, -35, 1595, 2692 },
+{	EPS_MSID_MEISHI, 		1051, 650, 981, 580, -30, -35, 1111, 744 },
+{	EPS_MSID_BUZCARD_89X50, 1051, 590, 981, 520, -30, -35, 1111, 684 },
+{	EPS_MSID_CARD_54X86, 	637, 1015, 567, 945, -30, -35, 697, 1109 },
+{	EPS_MSID_BUZCARD_55X91, 650, 1074, 580, 1004, -30, -35, 710, 1168 },
+{	EPS_MSID_ALBUM_L, 		1500, 2173, 1430, 2103, -30, -35, 1560, 2267 },
+{	EPS_MSID_ALBUM_A5, 		2480, 3578, 2410, 3508, -30, -35, 2540, 3672 },
+{	EPS_MSID_PALBUM_L_L, 	1500, 1051, 1430, 981, -30, -35, 1560, 1145 },
+{	EPS_MSID_PALBUM_2L, 	1500, 2102, 1430, 2032, -30, -35, 1560, 2196 },
+{	EPS_MSID_PALBUM_A5_L, 	2480, 1748, 2410, 1678, -30, -35, 2540, 1842 },
+{	EPS_MSID_PALBUM_A4, 	2480, 3507, 2410, 3437, -30, -35, 2540, 3601 },
+{	EPS_MSID_HIVISION, 		1200, 2133, 1130, 2063, -30, -35, 1260, 2227 },
+{	EPS_MSID_KAKU_2, 		2834, 3921, 2480, 3650, -30, -35, 2894, 4015 },
+{	EPS_MSID_ENV_C4_P, 		2704, 3826, 2480, 3555, -30, -35, 2764, 3920 },
+{	EPS_MSID_B6, 			1511, 2149, 1441, 1878, -30, -35, 1571, 2243 },
+{	EPS_MSID_KAKU_20, 		2704, 3826, 2480, 3555, -30, -35, 2764, 3920 },
+{	EPS_MSID_A5_24HOLE, 	1748, 2480, 1513, 2410, -30, -35, 1808, 2574 },
+{	EPS_MSID_CHOKEI_40, 	1062, 2657, 944, 2280, -30, -35, 1122, 2751 },
+{	EPS_MSID_A3NOBI, 		3885, 5704, 3815, 5634, -42, -35, 3969, 5798 },
+{	EPS_MSID_A3, 			3507, 4960, 3437, 4890, -42, -35, 3591, 5054 },
+{	EPS_MSID_B4, 			3035, 4299, 2965, 4229, -42, -35, 3119, 4393 },
+{	EPS_MSID_USB, 			3300, 5100, 3230, 5030, -42, -35, 3384, 5194 },
+{	EPS_MSID_11X14, 		3300, 4200, 3230, 4130, -42, -35, 3384, 4294 },
+{	EPS_MSID_B3, 			4299, 6082, 4229, 6012, -42, -35, 4383, 6176 },
+{	EPS_MSID_A2, 			4960, 7015, 4890, 6945, -42, -35, 5044, 7109 },
+{	EPS_MSID_USC, 			5100, 6600, 5030, 6530, -42, -35, 5184, 6694 },
+{	EPS_MSID_10X12, 		3000, 3600, 2930, 3530, -42, -35, 3084, 3694 },
+{	EPS_MSID_12X12, 		3600, 3600, 3530, 3530, -42, -35, 3684, 3694 },
+{	EPS_MSID_SP1, 			2480, 3188, 2410, 3118, -30, -35, 2540, 3282 },
+{	EPS_MSID_SP2, 			2480, 1759, 2410, 1689, -30, -35, 2540, 1853 },
+{	EPS_MSID_SP3, 			1181, 2007, 1111, 1937, -30, -35, 1241, 2101 },
+{	EPS_MSID_SP4, 			1535, 2149, 1465, 2079, -30, -35, 1595, 2243 },
+{	EPS_MSID_SP5, 			2267, 1559, 2197, 1489, -30, -35, 2327, 1653 },
+{	EPS_MSID_16K, 			2303, 3188, 2233, 3118, -30, -35, 2363, 3282 },
+{	EPS_MSID_8K, 			3188, 4606, 3118, 4536, -30, -35, 3248, 4700 },
 {   EPS_MSID_USER,             0,    0,    0,    0, -30, -35,    0,    0 },
+{	EPS_MSID_HALFCUT, 		4200, 5100, 4130, 5030, -30, -35, 4260, 5194 },
+{	EPS_MSID_16X20, 		4800, 6000, 4730, 5930, -30, -35, 4860, 6094 },
 {   -1,                        0,    0,    0,    0,   0,   0,    0,    0 }
 };
 
@@ -341,13 +372,21 @@ typedef enum _tagMEDIA_TYPE_ID_ {
 	EPS_MTID_LETTERHEAD       , /* 54  0x36,  "Letterhead\0"                                */
 	EPS_MTID_RECYCLED         , /* 55  0x37,  "Recycled\0"                                  */
 	EPS_MTID_COLOR            , /* 56  0x38,  "Color\0"                                     */
-	EPS_MTID_PLAIN_ROLL_STICKER=59, /* 59 0x3B "Plain Roll Sticker\0"                       */
-	EPS_MTID_GROSSY_ROLL_STICKER, /* 60 0x3C "Glossy Roll Sticker\0"                        */
+	EPS_MTID_BUSINESS_PLAIN   , /* 57  0x39,  "Business Plain Paper                         */
+	EPS_MTID_PLAIN_ROLL_STICKER=59, /* 59 0x3B"Plain Roll Sticker\0"                        */
+	EPS_MTID_GROSSY_ROLL_STICKER, /* 60 0x3C  "Glossy Roll Sticker\0"                       */
+	EPS_MTID_THICKPAPER1=65   , /* 65  0x41,  "Thick Paper 1\0"                             */
+	EPS_MTID_THICKPAPER2      , /* 66  0x42,  "Thick Paper 2\0"                             */
+	EPS_MTID_THICKPAPER3      , /* 67  0x43,  "Thick Paper 3\0"                             */
+	EPS_MTID_HIGH_QUALITY_PLAIN=70, /* 70 0x46"High Quality Plain Paper\0"                  */
+	EPS_MTID_BS_HALFGLOSSY_DS , /* 71  0x47,  "Bussines card Harf Glossy Double-sided\0"    */
     EPS_MTID_CDDVD         =91, /* 91  0x5B,  "CD/DVD Label\0"                              */
     EPS_MTID_CDDVDHIGH        , /* 92  0x5C,  "CD/DVD High Quality Label\0"                 */
     EPS_MTID_CDDVDGLOSSY      , /* 93  0x5D,  "CD/DVD Glossy Surface\0"                     */
     EPS_MTID_CLEANING      =99, /* 99  0x63,  "Cleaning Paper\0"                            */
-    EPS_MTID_UNKNOWN       =0xff/* unknown                                                  */
+    EPS_MTID_PLOOFING_WHITE_MAT=142,/*142  0x8E,  "Proofing Paper White Semimatte\0"        */
+	EPS_MTID_AUTO_PLAIN    =253,    /*253  0xFD,  "Auto Select(Plain Paper)\0"              */
+    EPS_MTID_UNKNOWN       =0xff/* unknown                                               */
 } MEDIA_TYPE_ID;
 
 
